import {
  Component,
  OnInit,
  OnDestroy,
  AfterContentInit,
  ChangeDetectorRef
} from '@angular/core';

import { Store, select } from '@ngrx/store';

import { Observable, Subscription } from 'rxjs';
import { map, catchError, take, tap } from 'rxjs/operators';

import { Port, Service, Host } from '@overflow/model/discovery';

import { InfraDisplayType, DiscoveryStatusType } from '../../../core/type';
import * as AppStore from '../../../store';
import * as InfraStore from '../../../store/infra/infra';


@Component({
  selector: 'app-infra-display',
  templateUrl: './display.component.html',
  styleUrls: ['./display.component.scss']
})
export class DisplayComponent implements OnInit, AfterContentInit, OnDestroy {
  private infraDisplayType$: Observable<InfraDisplayType>;

  displaySidebar = false;
  selectedInfraSubscription: Subscription | null;
  selectedInfra: { group: string, infra: Host | Port | Service } | null;

  displayDiscoveryStopping: boolean;
  discoveryStatusSubscription: Subscription | null;

  constructor(
    private store: Store<any>,
    private changeDetector: ChangeDetectorRef,
  ) {
  }

  ngOnInit(): void {
    const __this = this;

    this.infraDisplayType$ = this.store.pipe(select(AppStore.InfraSelector.InfraSelector.selectInfraDisplayType));

    this.selectedInfraSubscription = this.store.pipe(
      select(AppStore.InfraSelector.InfraSelector.selectSelectedInfra)
    ).pipe(
      map((_selectedInfra) => {
        if (null === _selectedInfra) {
          __this.displaySidebar = false;
          __this.selectedInfra = null;
        } else {
          __this.displaySidebar = true;
          __this.selectedInfra = _selectedInfra;
        }
        __this.changeDetector.detectChanges();
      }),
    ).subscribe();

    this.discoveryStatusSubscription = this.store.pipe(
      select(AppStore.DiscoverySelector.RequestSelector.selectDiscoveryStatus)
    ).pipe(
      map((_discoveryStatus) => {
        switch (_discoveryStatus) {
          case DiscoveryStatusType.Stopping: {
            __this.displayDiscoveryStopping = true;
          }
            break;
          default: {
            __this.displayDiscoveryStopping = false;

          }
            break;
        }
        __this.changeDetector.detectChanges();
      }),
    ).subscribe();

  }

  ngAfterContentInit(): void {
  }

  ngOnDestroy(): void {
    if (null !== this.selectedInfraSubscription) {
      this.selectedInfraSubscription.unsubscribe();
    }
    if (null !== this.discoveryStatusSubscription) {
      this.discoveryStatusSubscription.unsubscribe();
    }
  }

  onHideDetail() {
    this.store.dispatch(new InfraStore.ChangeSelectedInfra(null));
  }

  otherHostSelected(host: Host) {
    this.store.dispatch(new InfraStore.ChangeSelectedInfra({
      group: 'host',
      infra: host,
    }));
  }
}
