import { Component, OnInit, AfterContentInit, OnDestroy, } from '@angular/core';
import { Store, select } from '@ngrx/store';
import { take } from 'rxjs/operators';

import * as AppStore from '../../store';
import { InfraDisplayType } from '../../core/type';
import { Message } from 'primeng/primeng';

const { saveSvgAsPng, svgAsDataUri } = require('save-svg-as-png');

@Component({
  selector: 'app-menu-export-jpeg',
  templateUrl: './export-jpeg.component.html',
  styleUrls: ['./export-jpeg.component.scss'],
})
export class ExportJPEGComponent implements OnInit, AfterContentInit, OnDestroy {
  msgs: Message[] = [];

  constructor(
    private store: Store<any>,
  ) {
  }

  ngOnInit(): void {
  }

  ngAfterContentInit(): void {

  }

  ngOnDestroy(): void {

  }

  export() {
    const __this = this;
    this.store.pipe(
      take(1),
      select((state) => {
        const infraDisplayType = AppStore.InfraSelector.InfraSelector.selectInfraDisplayType(state);
        const infraDisplayElementRef = AppStore.InfraSelector.InfraSelector.selectInfraDisplayElementRef(state);

        if (InfraDisplayType.MAP !== infraDisplayType) {
          this.msgs = [];
          this.msgs.push({
            severity: 'error',
            summary: 'Invalid Display Type',
            detail: 'Export JPEG is only supported for Map Display type'
          });
          return;
        }

        // svgAsDataUri(infraDisplayElementRef.nativeElement, {}, function (uri) {
        //   console.log(`uri: ${uri}`);
        // });
        saveSvgAsPng(infraDisplayElementRef.nativeElement, 'diagram.jpeg', { backgroundColor: '#ffffff', encoderType: 'image/jpeg' });
      }),
    ).subscribe();
  }
}
