import { combineLatest, Observable } from 'rxjs';
import { Store } from '@ngrx/store';

import { DiscoverHost, DiscoverPort, DiscoverService, Zone, Host, Port } from '@overflow/model/discovery';

import * as AppStore from '../../store';
import { DiscoverRequestInfo } from '../model';
import { DiscoverySession } from '../discovery/discovery-session';

export class DiscoveryUtil {
  /**
   * name
   */
  public static getRequestInfo(store: Store<any>): Observable<DiscoverRequestInfo> {
    return combineLatest(
      store.select(AppStore.EnvironmentSelector.UserSelector.selectMemberID),
      store.select(AppStore.DiscoverySelector.ConfigSelector.selectZone),
      store.select(AppStore.DiscoverySelector.ConfigSelector.selectHost),
      store.select(AppStore.DiscoverySelector.ConfigSelector.selectPort),
      store.select(AppStore.DiscoverySelector.ConfigSelector.selectDiscoverHost),
      store.select(AppStore.DiscoverySelector.ConfigSelector.selectDiscoverPort),
      store.select(AppStore.DiscoverySelector.ConfigSelector.selectDiscoverService),
      (
        memberID: string,
        zone: Zone, host: Host, port: Port,
        discoverHost: DiscoverHost, discoverPort: DiscoverPort, discoverService: DiscoverService) => {
        return {
          requesterID: memberID,
          zone,
          host,
          port,
          discoverHost,
          discoverPort,
          discoverService,
        };
      }
    );
  }

  public static getDiscoverySession(store: Store<any>): Observable<DiscoverySession> {
    return combineLatest(
      store.select(AppStore.DiscoverySelector.RequestSelector.selectDiscoverySession),
      (discoverySession: DiscoverySession) => {
        return discoverySession;
      }
    );
  }
}
