import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { Actions, Effect, ofType } from '@ngrx/effects';
import { of } from 'rxjs';
import { catchError, exhaustMap, map, tap } from 'rxjs/operators';

import { Interface } from '@overflow/model/net/nic';

import * as AppStore from '../../app';
import { InterfacesSuccess, InterfacesFailure, Interfaces, ActionType } from './interfaces.action';
import { MachineService } from '../../../service/machine.service';

@Injectable()
export class InterfacesEffects {
  @Effect()
  appInit$ = this.actions$.pipe(
    ofType<AppStore.AppInit>(AppStore.ActionType.AppInit),
    map(() =>
      new Interfaces()
    )
  );

  @Effect()
  interfaces$ = this.actions$.pipe(
    ofType<Interfaces>(ActionType.Interfaces),
    exhaustMap(() => this.machineService.interfaces()
      .pipe(
        map((ifaces: Interface[]) => new InterfacesSuccess(ifaces)),
        catchError(error => of(new InterfacesFailure({ error }))),
      )
    )
  );


  constructor(
    private actions$: Actions,
    private router: Router,
    private machineService: MachineService,
  ) { }
}
